pub struct TxInputInfo {
pub outpoint: OutPoint,
pub max_witness_len: usize,
pub redeem_script: ScriptBuf,
pub serial_id: u64,
}Expand description
Contains info about a utxo used for funding a DLC contract
Fields
outpoint: OutPointThe outpoint for the utxo
max_witness_len: usizeThe maximum witness length
redeem_script: ScriptBufThe redeem script
serial_id: u64The serial id for the input that will be used for ordering inputs of the fund transaction